==> computenest_cli-1.9.5-py3-none-any.whl: computenestcli/common/constant.py <==
SUPPORT_REGION_IDS = 'SupportRegionIds'
ARTIFACT_TYPE = 'ArtifactType'
ARTIFACT_BUILD_TYPE = 'ArtifactBuildType'
ARTIFACT_PROPERTY = 'ArtifactProperty'
ARTIFACT_BUILD_PROPERTY = 'ArtifactBuildProperty'
REGION_ID = 'RegionId'
IMAGE_ID = 'ImageId'
COMMODITY_CODE = 'CommodityCode'
COMMODITY_VERSION = 'CommodityVersion'
URL = 'Url'
ARTIFACT_NAME = 'ArtifactName'
VERSION_NAME = 'VersionName'
DESCRIPTION = 'Description'
FILE_PATH = 'FilePath'
PARAMETERS = 'Parameters'
TARGET_IMAGE_NAME = 'targetImageName'
SOURCE_IMAGE_ID = 'SourceImageId'
COMMAND_TYPE = 'CommandType'
COMMAND_CONTENT = 'CommandContent'
IMAGE = 'Image'
ARTIFACT = 'Artifact'
DEPLOY_METADATA = 'DeployMetadata'
SUPPLIER_DEPLOY_METADATA = 'SupplierDeployMetadata'
SUPPLIER_TEMPLATE_CONFIGS = 'SupplierTemplateConfigs'
IS_SUPPORT_OPERATED = 'IsSupportOperated'
ALARM_METADATA = 'AlarmMetadata'
DURATION = 'Duration'
LICENSE_METADATA = 'LicenseMetadata'
LOG_METADATA = 'LogMetadata'
RESOURCE_GROUP_ID = 'ResourceGroupId'
SOURCE_SERVICE_ID = 'SourceServiceId'
SOURCE_SERVICE_VERSION = 'SourceServiceVersion'
TENANT_TYPE = 'TenantType'
TRIAL_DURATION = 'TrialDuration'
UPGRADE_METADATA = 'UpgradeMetadata'
POLICY_NAMES = 'PolicyNames'
FILE_ARTIFACT_RELATION = 'FileArtifactRelation'
ARTIFACT_RELATION = 'ArtifactRelation'
ARTIFACT_ID = 'ArtifactId'
ARTIFACT_VERSION = 'ArtifactVersion'
IMAGE_BUILDER = 'ImageBuilder'
ROLE_NAME = 'RoleName'
PARAMETER_KEY = 'ParameterKey'
PARAMETER_MAPPINGS = 'ParameterMappings'
PARAMETER_VALUE_MAPPING = 'ParameterValueMapping'
VPC_ID = 'VpcId'
ZONE_ID = 'ZoneId'
VSWITCH_ID = 'VSwitchId'
FILE = 'File'
SERVICE = 'Service'
ECS_IMAGE = 'EcsImage'
SERVICE_INFO = 'ServiceInfo'
TEMPLATE_CONFIGS = 'TemplateConfigs'
LOCALE = 'Locale'
SHORT_DESCRIPTION = 'ShortDescription'
NAME = 'Name'
DEPLOY_TYPE = 'DeployType'
SERVICE_TYPE = 'ServiceType'
PREDEFINED_PARAMETERS = 'PredefinedParameters'
HIDDEN_PARAMETER_KEYS = 'HiddenParameterKeys'
OPERATION_METADATA = 'OperationMetadata'
TEMP_PATH = '/tmp/.computenest/'
CODE_REPO = 'CodeRepo'
PLATFORM = 'Platform'
OWNER = 'Owner'
BRANCH = 'Branch'
ACR_IMAGE = 'AcrImage'
REPO_NAME = 'RepoName'
REPO_ID = 'RepoId'
TAG = 'Tag'
REPO_TYPE = 'RepoType'
BUILD_TYPE = 'BuildType'
CUSTOM_PARAMETERS = 'CustomParameters'
DOCKER_BUILD_ARGS = 'DockerBuildArgs'
BUILD_ARGS = 'BuildArgs'
DOCKER_BUILD_ARGUMENT_NAME = 'ArgumentName'
DOCKER_BUILD_ARGUMENT_VALUE = 'ArgumentValue'
DOCKER_REPO_URL = 'DockerRepoUrl'
DOCKER_REPO_TYPE = 'DockerRepo'
DOCKER_FILE_TYPE = 'DockerFile'
DOCKER_FILE_PATH = 'DockerFilePath'
SOURCE_CONTAINER_IMAGE = 'SourceContainerImage'
HELM_REPO_TYPE = 'HelmRepo'
HELM_PACKAGE_TYPE = 'HelmPackage'
HELM_REPO_URL = 'HelmRepoUrl'
HELM_CHART_PATH = 'HelmChartPath'
ACR_IMAGE_ARTIFACT_RELATION = 'AcrImageArtifactRelation'
ACR_IMAGE_BUILDER = 'ArcImageBuilder'
HELM_CHART = 'HelmChart'
HELM_CHART_ARTIFACT_RELATION = 'HelmChartArtifactRelation'
WHETHER_CREATE_VPC = 'whetherCreateVpc'
OOS_ASSUME_ROLE = 'OOSAssumeRole'
INSTANCE_TYPE = 'InstanceType'
ALLOWED_REGIONS = 'AllowedRegions'
DEFAULT_ENV_FILE_PATH = 'DefaultEnvFilePath'
ZONE_ID = 'zoneId'
VERSION = 'Version'
SHARE_TYPE = 'ShareType'
APPROVAL_TYPE = 'ApprovalType'
MANAGED = 'managed'
PRIVATE = 'private'
GET_UPDATE_OSS_PRIVATE_CREDENTIALS = 'private'
GET_UPDATE_OSS_PUBLIC_CREDENTIALS = 'public'
AP_SOUTHEAST_1 = 'ap-southeast-1'
CN_HANGZHOU = 'cn-hangzhou'
BACK_VERSION = 'back'
CREDENTIALS_PATH = '~/.computenestcli/credentials'
ACCESS_KEY_ID = 'access_key_id'
ACCESS_KEY_SECRET = 'access_key_secret'
SECURITY_TOKEN = 'security_token'
DEFAULT_EXPORT_FILE_NAME = 'config.yaml'
SUPPORTED_PROJECTS_RESOURCE_DIR = 'computenestcli.resources'
SUPPORTED_PROJECTS_NAME = 'supported_projects.yaml'
ARCHITECTURE_DIAGRAM_URL = "ArchitectureDiagramUrl"
BASE64 = 'Base64'
STATUS = 'Status'

==> computenest_cli-1.9.6-py3-none-any.whl: computenestcli/common/constant.py <==
SUPPORT_REGION_IDS = 'SupportRegionIds'
ARTIFACT_TYPE = 'ArtifactType'
ARTIFACT_BUILD_TYPE = 'ArtifactBuildType'
ARTIFACT_PROPERTY = 'ArtifactProperty'
ARTIFACT_BUILD_PROPERTY = 'ArtifactBuildProperty'
REGION_ID = 'RegionId'
IMAGE_ID = 'ImageId'
COMMODITY_CODE = 'CommodityCode'
COMMODITY_VERSION = 'CommodityVersion'
URL = 'Url'
ARTIFACT_NAME = 'ArtifactName'
VERSION_NAME = 'VersionName'
DESCRIPTION = 'Description'
FILE_PATH = 'FilePath'
PARAMETERS = 'Parameters'
TARGET_IMAGE_NAME = 'targetImageName'
SOURCE_IMAGE_ID = 'SourceImageId'
COMMAND_TYPE = 'CommandType'
COMMAND_CONTENT = 'CommandContent'
IMAGE = 'Image'
ARTIFACT = 'Artifact'
DEPLOY_METADATA = 'DeployMetadata'
SUPPLIER_DEPLOY_METADATA = 'SupplierDeployMetadata'
SUPPLIER_TEMPLATE_CONFIGS = 'SupplierTemplateConfigs'
IS_SUPPORT_OPERATED = 'IsSupportOperated'
ALARM_METADATA = 'AlarmMetadata'
DURATION = 'Duration'
LICENSE_METADATA = 'LicenseMetadata'
LOG_METADATA = 'LogMetadata'
RESOURCE_GROUP_ID = 'ResourceGroupId'
SOURCE_SERVICE_ID = 'SourceServiceId'
SOURCE_SERVICE_VERSION = 'SourceServiceVersion'
TENANT_TYPE = 'TenantType'
TRIAL_DURATION = 'TrialDuration'
UPGRADE_METADATA = 'UpgradeMetadata'
POLICY_NAMES = 'PolicyNames'
FILE_ARTIFACT_RELATION = 'FileArtifactRelation'
ARTIFACT_RELATION = 'ArtifactRelation'
ARTIFACT_ID = 'ArtifactId'
ARTIFACT_VERSION = 'ArtifactVersion'
IMAGE_BUILDER = 'ImageBuilder'
ROLE_NAME = 'RoleName'
PARAMETER_KEY = 'ParameterKey'
PARAMETER_MAPPINGS = 'ParameterMappings'
PARAMETER_VALUE_MAPPING = 'ParameterValueMapping'
VPC_ID = 'VpcId'
ZONE_ID = 'ZoneId'
VSWITCH_ID = 'VSwitchId'
FILE = 'File'
SERVICE = 'Service'
ECS_IMAGE = 'EcsImage'
SERVICE_INFO = 'ServiceInfo'
TEMPLATE_CONFIGS = 'TemplateConfigs'
LOCALE = 'Locale'
SHORT_DESCRIPTION = 'ShortDescription'
NAME = 'Name'
DEPLOY_TYPE = 'DeployType'
SERVICE_TYPE = 'ServiceType'
PREDEFINED_PARAMETERS = 'PredefinedParameters'
HIDDEN_PARAMETER_KEYS = 'HiddenParameterKeys'
OPERATION_METADATA = 'OperationMetadata'
TEMP_PATH = '/tmp/.computenest/'
CODE_REPO = 'CodeRepo'
PLATFORM = 'Platform'
OWNER = 'Owner'
BRANCH = 'Branch'
ACR_IMAGE = 'AcrImage'
REPO_NAME = 'RepoName'
REPO_ID = 'RepoId'
TAG = 'Tag'
REPO_TYPE = 'RepoType'
BUILD_TYPE = 'BuildType'
CUSTOM_PARAMETERS = 'CustomParameters'
DOCKER_BUILD_ARGS = 'DockerBuildArgs'
BUILD_ARGS = 'BuildArgs'
DOCKER_BUILD_ARGUMENT_NAME = 'ArgumentName'
DOCKER_BUILD_ARGUMENT_VALUE = 'ArgumentValue'
DOCKER_REPO_URL = 'DockerRepoUrl'
DOCKER_REPO_TYPE = 'DockerRepo'
DOCKER_COMPOSE = "DockerCompose"
DOCKER_FILE_TYPE = 'DockerFile'
DOCKER_FILE_PATH = 'DockerFilePath'
SOURCE_CONTAINER_IMAGE = 'SourceContainerImage'
HELM_REPO_TYPE = 'HelmRepo'
HELM_PACKAGE_TYPE = 'HelmPackage'
HELM_REPO_URL = 'HelmRepoUrl'
HELM_CHART_PATH = 'HelmChartPath'
ACR_IMAGE_ARTIFACT_RELATION = 'AcrImageArtifactRelation'
ACR_IMAGE_BUILDER = 'ArcImageBuilder'
HELM_CHART = 'HelmChart'
HELM_CHART_ARTIFACT_RELATION = 'HelmChartArtifactRelation'
WHETHER_CREATE_VPC = 'whetherCreateVpc'
OOS_ASSUME_ROLE = 'OOSAssumeRole'
INSTANCE_TYPE = 'InstanceType'
ALLOWED_REGIONS = 'AllowedRegions'
DEFAULT_ENV_FILE_PATH = 'DefaultEnvFilePath'
ZONE_ID = 'zoneId'
VERSION = 'Version'
SHARE_TYPE = 'ShareType'
APPROVAL_TYPE = 'ApprovalType'
MANAGED = 'managed'
PRIVATE = 'private'
GET_UPDATE_OSS_PRIVATE_CREDENTIALS = 'private'
GET_UPDATE_OSS_PUBLIC_CREDENTIALS = 'public'
AP_SOUTHEAST_1 = 'ap-southeast-1'
CN_HANGZHOU = 'cn-hangzhou'
BACK_VERSION = 'back'
COMPUTENEST_CREDENTIALS_PATH = '~/.computenestcli/credentials'
ALIYUN_CLI_CREDENTIALS_PATH = '~/.aliyun/config.json'
ACCESS_KEY_ID = 'access_key_id'
ACCESS_KEY_SECRET = 'access_key_secret'
SECURITY_TOKEN = 'security_token'
DEFAULT_EXPORT_FILE_NAME = 'config.yaml'
SUPPORTED_PROJECTS_RESOURCE_DIR = 'computenestcli.resources'
SUPPORTED_PROJECTS_NAME = 'supported_projects.yaml'
ARCHITECTURE_DIAGRAM_URL = "ArchitectureDiagramUrl"
BASE64 = 'Base64'
STATUS = 'Status'
TERRAFORM_DEPLOY_TYPE = 'terraform'
TERRAFORM_STRUCTURE = 'infrastructure'
